# director

_Perform automated testing of Tkinter GUI applications_

Director is a tool that allows automated acceptance testing
of Tkinter GUI applications.

The tool is designed for automated assessment of introductory
programming assignments.
As such, there is included support to recognize GUI widgets
based upon a description of their functionality.
